==> sunny-foundation-0.3.35.tgz: package/PluggableRouter/index.tsx <==
import React, { Attributes, ReactNode } from 'react'
import {
  matchPath,
  Redirect,
  RouteComponentProps,
  RouteProps,
  Router,
  Switch as RouterSwitch
} from 'react-router'
import history from './history'

export * from './transform'

/**
 * 可拔插路由
 * @deprecated since 0.1.5. Just use Router instead.
 */
export default function PluggableRouter ({ children, ...props }) {
  return <Router history={history} {...props}>{children}</Router>
}

/**
 * 可拔插路由模块的Switch组件
 * 对原版Switch进行封装，加上No Match默认行为，用来满足嵌套路由全局默认No Match使用场景
 */
export function Switch ({ children, noMatch = '/404', ...props }) {
  return <RouterSwitch {...props}>
    {children}
    <Redirect to={noMatch} />
  </RouterSwitch>
}

export interface PluggableRoute extends Attributes, RouteProps {
  name?: string
  /**
   * 默认会使用path属性确定路由嵌套关系。该属性在不影响path原有功能的情况下，重定义路由嵌套关系。
   * Note:
   * - 运行时会始终为string类型
   * - 默认从path取值
   */
  nest?: string | string[]
  // 跟兄弟节点排序
  sort?: number,
  // route path中的动态参数由params替换
  toPath(params?: object): string,
  /**
   * @deprecated will be removed in next major version
   */
  getNest(): string,
  // [content: ]: FunctionComponent | ClassicComponent
  [key: string]: any
}

export interface PluggableRoutes {
  [RouteKey: string]: PluggableRoute
}

export interface PluggableRouterProps<Params = any, C = any, S = any> extends RouteComponentProps<Params, C, S> {
  // 当前路由配置
  route: PluggableRoute
  // 所有路由配置。通过route key访问
  routes: PluggableRoutes
  // 当前路由的子路由组件集合。通过route key访问
  childrenRoutes?: {
    [RouteKey: string]: ReactNode
  }
}

/**
 * @deprecated since version 0.1.4, please use PluggableRouterProps instead.
 */
export interface PluggableRouterComponentProps<Params = any, C = any, S = any> extends PluggableRouterProps<Params, C, S> {
  // 当前路由的子路由组件集合。通过route key访问
  childrenRoutes: {
    [RouteKey: string]: ReactNode
  }
}

/**
 * 判断传入的route配置对象是否匹配当前pathname
 * 典型用例：
 * - 过滤父级嵌套路由
 */
export function matchCurrentPath (route: RouteProps) {
  return matchPath(
    window.location.pathname,
    Object.assign({ exact: true }, route)
  ) !== null
}

==> sunny-foundation-0.3.37.tgz: package/PluggableRouter/index.tsx <==
import React, { Attributes, ReactNode } from 'react'
import {
  matchPath,
  Redirect,
  RouteComponentProps,
  RouteProps,
  Router,
  Switch as RouterSwitch
} from 'react-router'
import history from './history'

export * from './transform'

/**
 * 可拔插路由
 * @deprecated since 0.1.5. Just use Router instead.
 */
export default function PluggableRouter ({ children, ...props }) {
  return <Router history={history} {...props}>{children}</Router>
}

/**
 * 可拔插路由模块的Switch组件
 * 对原版Switch进行封装，加上No Match默认行为，用来满足嵌套路由全局默认No Match使用场景
 */
export function Switch ({ children, noMatch = '/404', ...props }) {
  return <RouterSwitch {...props}>
    {children}
    <Redirect to={noMatch} />
  </RouterSwitch>
}

export interface PluggableRoute extends Attributes, RouteProps {
  name?: string
  /**
   * 默认会使用path属性确定路由嵌套关系。该属性在不影响path原有功能的情况下，重定义路由嵌套关系。
   * Note:
   * - 运行时会始终为string类型
   * - 默认从path取值
   */
  nest?: string | string[]
  // 跟兄弟节点排序
  sort?: number,
  // route path中的动态参数由params替换
  toPath(params?: object): string,
  /**
   * @deprecated will be removed in next major version
   */
  getNest(): string,
  // [content: ]: FunctionComponent | ClassicComponent
  [key: string]: any
}

export interface PluggableRoutes {
  [RouteKey: string]: PluggableRoute
}

export interface PluggableRouterProps<Params extends { [K in keyof Params]?: string } = any, C = any, S = any> extends RouteComponentProps<Params, C, S> {
  // 当前路由配置
  route: PluggableRoute
  // 所有路由配置。通过route key访问
  routes: PluggableRoutes
  // 当前路由的子路由组件集合。通过route key访问
  childrenRoutes?: {
    [RouteKey: string]: ReactNode
  }
}

/**
 * @deprecated since version 0.1.4, please use PluggableRouterProps instead.
 */
export interface PluggableRouterComponentProps<Params extends { [K in keyof Params]?: string } = any, C = any, S = any> extends PluggableRouterProps<Params, C, S> {
  // 当前路由的子路由组件集合。通过route key访问
  childrenRoutes: {
    [RouteKey: string]: ReactNode
  }
}

/**
 * 判断传入的route配置对象是否匹配当前pathname
 * 典型用例：
 * - 过滤父级嵌套路由
 */
export function matchCurrentPath (route: RouteProps) {
  return matchPath(
    window.location.pathname,
    Object.assign({ exact: true }, route)
  ) !== null
}
